@@ -3,7 +3,7 @@ package RPerl::Algorithm;
 use strict;
 use warnings;
 use RPerl::AfterSubclass;
-our $VERSION = 0.005_000;
+our $VERSION = 0.006_200;
 
 # [[[ OO INHERITANCE ]]]
 use parent qw(RPerl::CompileUnit::Module::Class);    # no non-system inheritance, only inherit from base class
@@ -14,16 +14,24 @@ use RPerl::CompileUnit::Module::Class;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 
 # [[[ OO PROPERTIES ]]]
-our hashref $properties = {};
+our hashref $properties = { complexity => my string $TYPED_complexity = undef };
 
 # [[[ SUBROUTINES & OO METHODS ]]]
 
+# [ INHERITANCE TESTING ]
+
 our void::method $inherited__Algorithm = sub {
     ( my RPerl::Algorithm $self, my string $person ) = @ARG;
     RPerl::diag(
         'in PERLOPS_PERLTYPES Algorithm->inherited__Algorithm(), have ::class($self) = ' . ::class($self) . ' and $person = ' . $person . ', FNORD' . "\n" );
 };
 
+our void::method $inherited__Algorithm_complexity_modify = sub {
+    ( my RPerl::Algorithm $self, my string $complexity_new ) = @ARG;
+    RPerl::diag( 'in PERLOPS_PERLTYPES Algorithm->inherited__Algorithm_complexity_modify(), have ::class($self) = ' . ::class($self) . ' and $complexity_new = ' . $complexity_new . ', FNORD' . "\n" );
+    $self->{complexity} = $complexity_new;
+};
+
 #our void::method $inherited = sub {
 #    ( my RPerl::Algorithm $self, my string $person ) = @ARG;
 #    RPerl::diag('in PERLOPS_PERLTYPES Algorithm->inherited(), have ::class($self) = ' . ::class($self) . ' and $person = ' . $person . ', IS' . "\n");
