@@ -3,7 +3,7 @@ package RPerl::Algorithm::Inefficient;
 use strict;
 use warnings;
 use RPerl::AfterSubclass;
-our $VERSION = 0.005_000;
+our $VERSION = 0.008_200;
 
 # [[[ OO INHERITANCE ]]]
 use parent qw(RPerl::Algorithm);
@@ -14,17 +14,31 @@ use RPerl::Algorithm;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 
 # [[[ OO PROPERTIES ]]]
-our hashref $properties = {};
+our hashref $properties = { usefulness => my string $TYPED_usefulness = undef };
 
 # [[[ SUBROUTINES & OO METHODS ]]]
 
+# [ INHERITANCE TESTING ]
+
 our void::method $inherited__Inefficient = sub {
-    ( my object $self, my string $person ) = @ARG;
+    ( my RPerl::Algorithm::Inefficient $self, my string $person ) = @ARG;
     RPerl::diag( 'in PERLOPS_PERLTYPES Inefficient->inherited__Inefficient(), have ::class($self) = ' . ::class($self) . ' and $person = ' . $person . ', FLUFFY' . "\n" );
 };
 
+our void::method $inherited__Inefficient_usefulness_modify = sub {
+    ( my RPerl::Algorithm::Inefficient $self, my string $usefulness_new ) = @ARG;
+    RPerl::diag( 'in PERLOPS_PERLTYPES Inefficient->inherited__Inefficient_usefulness_modify(), have ::class($self) = ' . ::class($self) . ' and $usefulness_new = ' . $usefulness_new . ', FLUFFY' . "\n" );
+    $self->{usefulness} = $usefulness_new;
+};
+
+our void::method $inherited__Inefficient_complexity_modify = sub {
+    ( my RPerl::Algorithm::Inefficient $self, my string $complexity_new ) = @ARG;
+    RPerl::diag( 'in PERLOPS_PERLTYPES Inefficient->inherited__Inefficient_complexity_modify(), have ::class($self) = ' . ::class($self) . ' and $complexity_new = ' . $complexity_new . ', FLUFFY' . "\n" );
+    $self->{complexity} = $complexity_new;
+};
+
 our void::method $inherited = sub {
-    ( my object $self, my string $person ) = @ARG;
+    ( my RPerl::Algorithm::Inefficient $self, my string $person ) = @ARG;
     RPerl::diag('in PERLOPS_PERLTYPES Inefficient->inherited(), have ::class($self) = ' . ::class($self) . ' and $person = ' . $person . ', INCOMPATIBLE' . "\n");
 };
 
