@@ -7,7 +7,7 @@ package RPerl::Compiler;
 use strict;
 use warnings;
 use RPerl::AfterSubclass;
-our $VERSION = 0.020_000;
+our $VERSION = 0.025_000;
 
 # [[[ OO INHERITANCE ]]]
 use parent qw(RPerl::CompileUnit::Module::Class);
@@ -51,6 +51,137 @@ our hashref_hashref $filename_suffixes_supported = {
 
 # [[[ SUBROUTINES ]]]
 
+our string_arrayref $find_parents = sub {
+    ( my string $file_name, my boolean $find_grandparents_recurse, my string_hashref $modes ) = @_;
+#    RPerl::diag( 'in Compiler::find_parents(), received $file_name = ' . $file_name . "\n" );
+
+    # trim unnecessary (and possibly problematic) absolute paths from input file name
+    $file_name = post_processor__absolute_path_delete($file_name);
+#    RPerl::diag( 'in Compiler::find_parents(), have possibly-trimmed $file_name = ' . $file_name . "\n" );
+
+    my string_arrayref $parents = [];
+
+    if ( not -f $file_name ) {
+        die 'ERROR ECOCOPA00, COMPILER, FIND PARENTS: File not found, ' . q{'} . $file_name . q{'} . ', dying' . "\n";
+    }
+
+    open my filehandleref $FILE_HANDLE, '<', $file_name
+        or die 'ERROR ECOCOPA01, COMPILER, FIND PARENTS: Cannot open file ' . q{'} . $file_name . q{'} . ' for reading, ' . $OS_ERROR . ', dying' . "\n";
+
+    # read in input file, match on 'use' includes for parents
+    my string $file_line;
+    my string $top_level_package_name = undef;
+    my boolean $use_rperl = 0;
+
+    # NEED FIX: do not make recursive calls until after closing file, to avoid
+    # ERROR ECOCOPA01, COMPILER, FIND PARENTS: Cannot open file Foo/Bar.pm for reading, Too many open files, dying
+    while ( $file_line = <$FILE_HANDLE> ) {
+#        RPerl::diag('in Compiler::find_parents(), top of while loop, have $file_line = ' . $file_line . "\n");
+
+        if ( $file_line =~ /^\s*package\s+[\w:]+\s*;\s*$/xms ) {
+            if ( not defined $top_level_package_name ) {
+                $top_level_package_name = $file_line;
+                $top_level_package_name =~ s/^\s*package\s+([\w:]+)\s*;\s*$/$1/gxms;
+            }
+            # DEV NOTE: for monolithic modules (more than one package), we only find parents of the first package, to avoid incorrect parent lists & infinite recursion
+            else {
+                last;
+            }
+        }
+
+        if ( $file_line =~ /^\s*use\s+[\w:]+/xms ) {
+#            RPerl::diag('in Compiler::find_parents(), found use line, have $file_line = ' . $file_line . "\n");
+            if (( $file_line =~ /use\s+RPerl\s*;/ ) or 
+                ( $file_line =~ /use\s+RPerl::AfterSubclass\s*;/ )) {
+                $use_rperl = 1;
+                next;
+            }
+            elsif ( $file_line =~ /use\s+lib/ ) {
+                die
+                    q{ERROR ECOCOPA02, COMPILER, FIND PARENTS: 'use lib...' not currently supported, please set @INC using the PERL5LIB environment variable, file }
+                    . q{'}
+                    . $file_name . q{'}
+                    . ', dying' . "\n";
+            }
+            elsif ( $file_line !~ /use\s+parent/ )
+            {
+                # safely ignore these not-parent uses
+                next;
+            }
+
+            # 'use RPerl;' must appear before any other 'use Foo;' statements, or else this is not a valid RPerl input file and we return empty deps
+            if (not $use_rperl) {
+                last; 
+            }
+
+            my string $package_file_name_included;
+            my string $package_name = $file_line;
+            # remove everything except the package name
+            $package_name =~ s/^(\s*)//gxms;  # strip leading whitespace
+            substr $package_name, 0, 14, q{};  # strip leading 'use parent qw('
+            $package_name =~ s/([\w:]+)(.*)$/$1/gxms;  # strip trailing everything
+#            RPerl::diag('in Compiler::find_parents(), have $package_name = ' . $package_name . "\n\n");
+
+            # safely skip base class for no parent inheritance
+            if ($package_name eq 'RPerl::CompileUnit::Module::Class') {
+                next;
+            }
+
+            my string $package_file_name = $package_name;
+            $package_file_name =~ s/::/\//gxms;    # replace double-colon :: scope delineator with forward-slash / directory delineator
+            $package_file_name .= '.pm';
+
+            # find specific included dependency file in @INC
+            foreach my string $INC_directory (@INC) {
+#                RPerl::diag( 'in Compiler::find_parents(), top of @INC foreach loop, have $INC_directory = ' . $INC_directory . "\n" );
+                $package_file_name_included = $INC_directory . '/' . $package_file_name;
+#                RPerl::diag( 'in Compiler::find_parents(), inside @INC foreach loop, have $package_file_name_included = ' . $package_file_name_included . "\n" );
+                if (-e $package_file_name_included) {
+#                    RPerl::diag( 'in Compiler::find_parents(), inside @INC foreach loop, have EXISTING $package_file_name_included = ' . $package_file_name_included . "\n" );
+                    last;
+                }
+                else {
+                    $package_file_name_included = q{};
+                }
+            }
+            if ($package_file_name_included eq q{}) {
+                die 'ERROR ECOCOPA04, COMPILER, FIND PARENTS: Failed to find package file ', q{'}, $package_file_name, q{'},
+                    ' in @INC, included from file ', q{'}, $file_name, q{'}, ', dying', "\n";
+            }
+
+            RPerl::diag( 'in Compiler::find_parents(), have $package_file_name_included = ' . $package_file_name_included . "\n" );
+
+            my string $package_file_name_included_relative = post_processor__absolute_path_delete( $package_file_name_included );
+            push @{$parents}, $package_file_name_included_relative;
+    
+#            RPerl::diag( 'in Compiler::find_parents(), have PRE-SUBDEPS $parents = ' . Dumper($parents) . "\n" );
+
+            if ($find_grandparents_recurse) {
+    
+                # recursively find grandparents
+                my string_arrayref $grandparents = find_parents( $package_file_name_included, $find_grandparents_recurse, $modes );
+    
+                # discard duplicate parents that now appear in grandparents
+                $parents = [ uniq @{$grandparents}, @{$parents} ];
+    
+#                RPerl::diag( 'in Compiler::find_parents(), have POST-SUBDEPS $parents = ' . Dumper($parents) . "\n" );
+            }
+        }
+    }
+
+    close $FILE_HANDLE
+        or die 'ERROR ECOCOPA05, COMPILER, FIND PARENTS: Cannot close file ' . q{'}
+        . $file_name . q{'}
+        . ' after reading, '
+        . $OS_ERROR
+        . ', dying' . "\n";
+
+#    RPerl::diag( 'in Compiler::find_parents(), returning $parents = ' . Dumper($parents) . "\n" );
+#    RPerl::diag('in Compiler::find_parents(), about to return, have $modes->{_enable_sse} = ' . Dumper($modes->{_enable_sse}) . "\n");
+#    RPerl::diag('in Compiler::find_parents(), about to return, have $modes->{_enable_gmp} = ' . Dumper($modes->{_enable_gmp}) . "\n");
+    return $parents;
+};
+
 our string_arrayref $find_dependencies = sub {
     ( my string $file_name, my boolean $find_subdependencies_recurse, my string_hashref $modes ) = @_;
 #    RPerl::diag( 'in Compiler::find_dependencies(), received $file_name = ' . $file_name . "\n" );
@@ -60,7 +191,7 @@ our string_arrayref $find_dependencies = sub {
 #    RPerl::diag( 'in Compiler::find_dependencies(), have possibly-trimmed $file_name = ' . $file_name . "\n" );
 
     my string_arrayref $dependencies = [];
-    my string_arrayref $pmc_disable_paths = [];
+#    my string_arrayref $pmc_disable_paths = [];  # DISABLE_DYNAMIC_DEPS_ANALYSIS
 
     if ( not -f $file_name ) {
         die 'ERROR ECOCODE00, COMPILER, FIND DEPENDENCIES: File not found, ' . q{'} . $file_name . q{'} . ', dying' . "\n";
@@ -83,20 +214,23 @@ our string_arrayref $find_dependencies = sub {
             # disable top-level PMC file before finding subdependencies
             $top_level_package_name = $file_line;
             $top_level_package_name =~ s/^\s*package\s+([\w:]+)\s*;\s*$/$1/gxms;
+=DISABLE_DYNAMIC_DEPS_ANALYSIS
             my string $pmc_disable_path = pmc_disable($top_level_package_name);
             if ($pmc_disable_path eq q{}) {
-#               my integer $eval_retval = eval_use($top_level_package_name);  # NEED ANSWER: do we need to care about $eval_retval?
-                eval_use($top_level_package_name);
+#               my integer $eval_retval = eval_use_dependencies($top_level_package_name);  # NEED ANSWER: do we need to care about $eval_retval?
+                eval_use_dependencies($top_level_package_name);
             }
             else {
                 push @{$pmc_disable_paths}, $pmc_disable_path;
             }
+=cut
         }
 
         # NEED FIX: remove hard-coded list of not-subdependency uses
         if ( $file_line =~ /^\s*use\s+[\w:]+/xms ) {
 #            RPerl::diag('in Compiler::find_dependencies(), found use line, have $file_line = ' . $file_line . "\n");
-            if ( $file_line =~ /use\s+RPerl\s*;/ ) {
+            if (( $file_line =~ /use\s+RPerl\s*;/ ) or 
+                ( $file_line =~ /use\s+RPerl::AfterSubclass\s*;/ )) {
                 $use_rperl = 1;
                 next;
             }
@@ -104,7 +238,6 @@ our string_arrayref $find_dependencies = sub {
                 or ( $file_line =~ /use\s+warnings\s*;/ )
                 or ( $file_line =~ /use\s+RPerl::CompileUnit::Module::Class\s*;/ )
                 or ( $file_line =~ /use\s+RPerl::Class\s*;/ )
-                or ( $file_line =~ /use\s+RPerl::AfterSubclass\s*;/ )
                 or ( $file_line =~ /use\s+RPerl::Config\s*;/ )
                 or ( $file_line =~ /use\s+\w+Perl::Config\s*;/ )    # DEV NOTE, CORRELATION #rp027: MathPerl::Config, PhysicsPerl::Config, etc
                 or ( $file_line =~ /use\s+parent/ )
@@ -135,7 +268,6 @@ our string_arrayref $find_dependencies = sub {
                 next;
             }
             elsif ( $file_line =~ /use\s+rperlgmp\s*;/ ) {
-
 #                RPerl::diag('in Compiler::find_dependencies(), found rperlgmp line, have $modes->{_enable_gmp} = ' . Dumper($modes->{_enable_gmp}) . "\n");
                 if ( ( not exists $modes->{_enable_gmp} ) or ( not defined $modes->{_enable_gmp} ) ) {
                     $modes->{_enable_gmp} = {};
@@ -153,24 +285,26 @@ our string_arrayref $find_dependencies = sub {
                     . ', dying' . "\n";
             }
 
-            # 'use RPerl;' must appear before any other 'use Foo;' statements, or else this is not a valid RPerl input file and we return empty deps
+            # 'use RPerl;' or 'use RPerl::AfterSubclass;' must appear before any other 'use Foo;' statements, or else this is not a valid RPerl input file and we return empty deps
             if (not $use_rperl) {
                 last; 
             }
 
-            # disable PMC file before finding subdependencies
             my string $package_file_name_included;
             my string $package_name = $file_line;
             $package_name =~ s/^\s*use\s+([\w:]+)\s*.*\s*;\s*$/$1/gxms;    # remove everything except the package name
-            my string $pmc_disable_path = pmc_disable($package_name);
+
+            # disable PMC file before finding subdependencies
+#            my string $pmc_disable_path = pmc_disable($package_name);  # DISABLE_DYNAMIC_DEPS_ANALYSIS
 
             my string $package_file_name = $package_name;
             $package_file_name =~ s/::/\//gxms;    # replace double-colon :: scope delineator with forward-slash / directory delineator
             $package_file_name .= '.pm';
 
             # find specific included dependency file in either %INC or @INC
+=DISABLE_DYNAMIC_DEPS_ANALYSIS
             if ($pmc_disable_path eq q{}) {
-                eval_use($package_name);
+                eval_use_dependencies($package_name);
                 if ( not exists $INC{$package_file_name} ) {
                     die 'ERROR ECOCODE03, COMPILER, FIND DEPENDENCIES: Failed to find package file ', q{'}, $package_file_name, q{'},
                         ' in %INC, included from file ', q{'}, $file_name, q{'}, ', dying', "\n";
@@ -178,6 +312,7 @@ our string_arrayref $find_dependencies = sub {
                 $package_file_name_included = $INC{$package_file_name};
             }
             else {
+=cut
                 foreach my string $INC_directory (@INC) {
 #                    RPerl::diag( 'in Compiler::find_dependencies(), top of @INC foreach loop, have $INC_directory = ' . $INC_directory . "\n" );
                     $package_file_name_included = $INC_directory . '/' . $package_file_name;
@@ -194,8 +329,10 @@ our string_arrayref $find_dependencies = sub {
                     die 'ERROR ECOCODE04, COMPILER, FIND DEPENDENCIES: Failed to find package file ', q{'}, $package_file_name, q{'},
                         ' in @INC, included from file ', q{'}, $file_name, q{'}, ', dying', "\n";
                 }
+=DISABLE_DYNAMIC_DEPS_ANALYSIS
                 push @{$pmc_disable_paths}, $pmc_disable_path;
             }
+=cut
 
 #            RPerl::diag( 'in Compiler::find_dependencies(), have $package_file_name_included = ' . $package_file_name_included . "\n" );
 
@@ -224,17 +361,20 @@ our string_arrayref $find_dependencies = sub {
         . $OS_ERROR
         . ', dying' . "\n";
 
+=DISABLE_DYNAMIC_DEPS_ANALYSIS
     # re-enable all PMC files after finding dependencies
     while (scalar @{$pmc_disable_paths}) {
         pmc_reenable(pop @{$pmc_disable_paths});
     }
+=cut
 
-    #    RPerl::diag( 'in Compiler::find_dependencies(), returning $dependencies = ' . Dumper($dependencies) . "\n" );
-    #    RPerl::diag('in Compiler::find_dependencies(), about to return, have $modes->{_enable_sse} = ' . Dumper($modes->{_enable_sse}) . "\n");
-    #    RPerl::diag('in Compiler::find_dependencies(), about to return, have $modes->{_enable_gmp} = ' . Dumper($modes->{_enable_gmp}) . "\n");
+#    RPerl::diag( 'in Compiler::find_dependencies(), returning $dependencies = ' . Dumper($dependencies) . "\n" );
+#    RPerl::diag('in Compiler::find_dependencies(), about to return, have $modes->{_enable_sse} = ' . Dumper($modes->{_enable_sse}) . "\n");
+#    RPerl::diag('in Compiler::find_dependencies(), about to return, have $modes->{_enable_gmp} = ' . Dumper($modes->{_enable_gmp}) . "\n");
     return $dependencies;
 };
 
+=DISABLE_DYNAMIC_DEPS_ANALYSIS
 # temporarily disable a package's PMC file, if it exists
 our string $pmc_disable = sub {
     ( my string $package_name ) = @_;
@@ -293,15 +433,12 @@ our boolean $pmc_reenable = sub {
     else { return 0; }
 };
 
-# use eval to perform a runtime use on a package
-our integer $eval_use = sub {
+# call RPerl::eval_use() to perform a runtime use on a package, with dependencies-specific warning message
+our integer $eval_use_dependencies = sub {
     ( my string $package_name ) = @_;
 #    RPerl::diag( 'in Compiler::eval_use(), received $package_name = ' . $package_name . "\n" );
 
-    my string $eval_string = 'use ' . $package_name . '; 1;';
-
-    #            RPerl::diag('in Compiler::find_dependencies(), about to call NON-DEP $eval_string = ' . $eval_string . "\n");
-    my integer $eval_retval = eval($eval_string);
+    my integer $eval_retval = RPerl::eval_use($package_name, 0);
 
 #    RPerl::diag('in Compiler::find_dependencies(), have POST-EVAL NON-DEP %INC = ' . Dumper(\%INC) . "\n");
     # warn instead of dying on eval error here and below, in order to preserve proper parser errors instead of weird eval errors
@@ -316,6 +453,7 @@ our integer $eval_use = sub {
 
     return $eval_retval;
 };
+=cut
 
 # [[[ COMPILE RPERL TO RPERL, TEST MODE ]]]
 # [[[ COMPILE RPERL TO RPERL, TEST MODE ]]]
@@ -1463,7 +1601,10 @@ our void $cpp_to_xsbinary__subcompile = sub {
 	#        }
 	#
 
-        RPerl::diag( 'in Compiler::cpp_to_xsbinary__subcompile(), have $subcompile_command =' . "\n\n" . $subcompile_command . "\n" );
+#        RPerl::diag( "\n" . 'in Compiler::cpp_to_xsbinary__subcompile(), have $subcompile_command =' . "\n\n" . $subcompile_command . "\n\n" );
+        RPerl::diag(  "\n\n" . $subcompile_command . "\n\n" );
+        if ( $ENV{RPERL_VERBOSE} or $RPerl::VERBOSE ) { RPerl::diag(  q{SUBCOMPILE:         Generate binary...     } ); }
+
 	# if ( $OSNAME eq 'MSWin32' || $stdout_select->can_read(0) ) { sysread SUBCOMPILE_STDOUT, $subcompile_command_stdout, 4096; }
 	#        if ( $OSNAME eq 'MSWin32' || $stderr_select->can_read(0) ) { sysread SUBCOMPILE_STDERR, $subcompile_command_stderr, 4096; }
 	#        waitpid $pid, 0;
