@@ -2,11 +2,11 @@
 package RPerl::DataType::Scalar;
 use strict;
 use warnings;
-use RPerl;
-our $VERSION = 0.002_010;
+use RPerl::AfterSubclass;
+our $VERSION = 0.003_000;
 
 # [[[ OO INHERITANCE ]]]
-our @ISA = ('RPerl::DataType');
+use parent qw(RPerl::DataType);
 use RPerl::DataType;
 
 # [[[ CRITICS ]]]
@@ -19,6 +19,8 @@ use RPerl::DataType;
 # DEV NOTE: do NOT overload Perl's 'scalar' keyword!!!
 package  # hide from PAUSE indexing
     scalartype;
-our @ISA = ('RPerl::DataType::Scalar');
+use strict;
+use warnings;
+use parent qw(RPerl::DataType::Scalar);
 
 1;  # end of class
