@@ -18,7 +18,8 @@ my integer $foo = 21 + 12;
 my integer $bar = 23 * 42;
 my number  $baz = to_number($bar) / $foo;
 my number  $zab = to_number($foo) / $bar;
-print 'have $foo = ' . to_string($foo) . "\n";
-print 'have $bar = ' . to_string($bar) . "\n";
-print 'have $baz = ' . to_string($baz) . "\n";
-print 'have $zab = ' . to_string($zab) . "\n";
+print 'have $foo = ', to_string($foo), "\n";
+print 'have $bar = ', to_string($bar), "\n";
+print 'have $baz = ', to_string($baz), "\n";
+print 'have $zab = ', to_string($zab), "\n";
+
