@@ -3,7 +3,7 @@ package RPerl::Operation::Expression::Operator::NamedUnary;
 use strict;
 use warnings;
 use RPerl::AfterSubclass;
-our $VERSION = 0.002_300;
+our $VERSION = 0.002_500;
 
 # [[[ OO INHERITANCE ]]]
 use parent qw(RPerl::Operation::Expression::Operator);
@@ -17,6 +17,7 @@ use RPerl::Operation::Expression::Operator;
 our hashref $properties = {};
 
 # [[[ OO PROPERTIES, CLASS PROPERTY AKA PACKAGE VARIABLE ]]]
+# DEV NOTE, CORRELATION #rp020: upon adding new named op file lib/RPerl/Operation/Expression/Operator/Named*/* also add in Named*.pm and rperloperations.*
 our string_hashref $NAMES = {
     'chdir'   => 'RPerl::Operation::Expression::Operator::NamedUnary::ChangeDirectory',
     'cos'     => 'RPerl::Operation::Expression::Operator::NamedUnary::Cosine',
@@ -27,12 +28,14 @@ our string_hashref $NAMES = {
     '-f'      => 'RPerl::Operation::Expression::Operator::NamedUnary::FileRegular',
     '-T'      => 'RPerl::Operation::Expression::Operator::NamedUnary::FileText',
     'length'  => 'RPerl::Operation::Expression::Operator::NamedUnary::Length',
+    'log'     => 'RPerl::Operation::Expression::Operator::NamedUnary::Log',
     'rand'    => 'RPerl::Operation::Expression::Operator::NamedUnary::Random',
     'scalar'  => 'RPerl::Operation::Expression::Operator::NamedUnary::Scalar',
-    'sin'     => 'RPerl::Operation::Expression::Operator::NamedUnary::Sine'
+    'sin'     => 'RPerl::Operation::Expression::Operator::NamedUnary::Sine',
+    'sqrt'    => 'RPerl::Operation::Expression::Operator::NamedUnary::SquareRoot'
 };
 
-# [[[ OO METHODS & SUBROUTINES ]]]
+# [[[ SUBROUTINES & OO METHODS ]]]
 
 our string_hashref::method $ast_to_rperl__generate = sub {
     ( my object $self, my string_hashref $modes) = @_;
