@@ -3,7 +3,7 @@ package RPerl::Operation::Expression::SubExpression::Literal::String;
 use strict;
 use warnings;
 use RPerl::AfterSubclass;
-our $VERSION = 0.003_000;
+our $VERSION = 0.006_000;
 
 # [[[ OO INHERITANCE ]]]
 use parent qw(RPerl::Operation::Expression::SubExpression::Literal);
@@ -60,6 +60,7 @@ our string_hashref::method $ast_to_cpp__generate__CPPOPS_CPPTYPES = sub {
     # replace single-quoted Perl string with double-quoted C++ string, both non-interpolated
     if ((substr $cpp_source_group->{CPP}, 0, 1) eq q{'}) {
         if ((substr $cpp_source_group->{CPP}, -1, 1) eq q{'}) {
+            $cpp_source_group->{CPP} =~ s/\"/\\\"/gxms;  # backslash-escape all double-quotes contained w/in single-quoted strings, before wrapping in non-escaped double-quotes
             substr $cpp_source_group->{CPP}, 0, 1, q{"};
             substr $cpp_source_group->{CPP}, -1, 1, q{"};
         }
@@ -69,6 +70,7 @@ our string_hashref::method $ast_to_cpp__generate__CPPOPS_CPPTYPES = sub {
     }
     elsif ((substr $cpp_source_group->{CPP}, 0, 2) eq 'q{') {
         if ((substr $cpp_source_group->{CPP}, -1, 1) eq '}') {
+            $cpp_source_group->{CPP} =~ s/\"/\\\"/gxms;  # backslash-escape all double-quotes contained w/in single-quoted strings, before wrapping in non-escaped double-quotes
             substr $cpp_source_group->{CPP}, 0, 2, q{"};
             substr $cpp_source_group->{CPP}, -1, 1, q{"};
         }
@@ -85,15 +87,26 @@ our string_hashref::method $ast_to_cpp__generate__CPPOPS_CPPTYPES = sub {
 #    RPerl::diag( 'in Literal::String->ast_to_cpp__generate__CPPOPS_CPPTYPES(), have $modes->{_inside_list_elements} = ' . $modes->{_inside_list_elements} . "\n" );
 #    RPerl::diag( 'in Literal::String->ast_to_cpp__generate__CPPOPS_CPPTYPES(), have $modes->{_inside_cat_operator} = ' . $modes->{_inside_cat_operator} . "\n" );
 
-    if (    (
-                ((exists $modes->{_inside_print_operator}) and (defined $modes->{_inside_print_operator}) and $modes->{_inside_print_operator}) or
-                ((exists $modes->{_inside_die_operator}) and (defined $modes->{_inside_die_operator}) and $modes->{_inside_die_operator})
-            ) and 
-            (exists $modes->{_inside_list_elements})  and (defined $modes->{_inside_list_elements})  and $modes->{_inside_list_elements}) {  # and
+    my boolean $cast_literal = 0;
+    if ((exists $modes->{_inside_class_properties}) and (defined $modes->{_inside_class_properties}) and $modes->{_inside_class_properties}) {
+        $cast_literal = 1;
+    }
+
+    if ((
+               ((exists $modes->{_inside_print_operator}) and (defined $modes->{_inside_print_operator}) and $modes->{_inside_print_operator}) or
+               ((exists $modes->{_inside_die_operator}) and (defined $modes->{_inside_die_operator}) and $modes->{_inside_die_operator})
+           ) and 
+           (exists $modes->{_inside_list_elements})  and (defined $modes->{_inside_list_elements})  and $modes->{_inside_list_elements}) {  # and
 #        not ((exists $modes->{_inside_cat_operator})   and (defined $modes->{_inside_cat_operator})   and $modes->{_inside_cat_operator})) {
 #    if (1) {
-        # don't cast string literals when inside print or die operator, and also inside list elements, and also NOT inside string concatenation operator;
+        # don't cast string literals when:
+        # inside OO class properties; OR
+        # inside print or die operator, and also inside list elements, and also NOT inside string concatenation operator;
         # cout << will automatically detect type
+        $cast_literal = 1;
+    }
+
+    if ($cast_literal) {
         $cpp_source_group->{CPP} = $cpp_source_group->{CPP};
     }
     else {
