@@ -11,7 +11,5 @@ our $VERSION = 0.001_000;
 
 # [[[ OPERATIONS ]]]
 
-our integer $foo = sub {
-    return 23;
-};
+our integer $foo = sub { return 23; };
 foo();
