@@ -11,12 +11,7 @@ our $VERSION = 0.001_000;
 
 # [[[ OPERATIONS ]]]
 
-foreach my string $key (
-    sort keys %{
-        my integer_hashref $TYPED_i_hash
-            = { a => 10, b => 20, c => 30, d => 40, e => 50 }
-    }
-    )
+foreach my string $key ( sort keys %{ my integer_hashref $TYPED_i_hash = { a => 10, b => 20, c => 30, d => 40, e => 50 } })
 {
     print '$key = ', $key, "\n";
 }
